@@ -1,7 +1,7 @@
 //muroar.c:
 
 /*
- *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2009,2010
+ *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2009-2011
  *
  *  This file is part of µRoar,
  *  a minimalist library to access a RoarAudio Sound Server.
@@ -22,7 +22,9 @@
 
 #include "muroar.h"
 #include <string.h>
+#ifndef NO_STDINT_H
 #include <stdint.h>
+#endif
 #include <unistd.h>
 #include <stdlib.h>
 #include <stdio.h> /* for snprintf() */
@@ -35,7 +37,8 @@
 #define _HAVE_ERRNO
 #include <sys/socket.h>
 #include <netinet/in.h>
-#if defined(AF_UNIX)
+#if !defined(__WIN32) && defined(AF_UNIX) && !defined(NO_AF_UNIX)
+#define HAVE_AF_UNIX
 #include <sys/un.h>
 #endif
 #include <netdb.h>
@@ -106,7 +109,7 @@ static void muroar_init_win32 (void) {
 static int muroar_open_socket (char * server) {
  struct hostent     * he;
  struct sockaddr_in   in;
-#if !defined(__WIN32) && defined(AF_UNIX)
+#ifdef HAVE_AF_UNIX
  struct sockaddr_un   un;
 #endif
  int fh = -1;
@@ -125,7 +128,7 @@ static int muroar_open_socket (char * server) {
 // Handle AF_UNIX Sockets,
 // do not build on broken systems like win32 not
 // supporting the AF_UNIX sockets.
-#if !defined(__WIN32) && defined(AF_UNIX)
+#ifdef HAVE_AF_UNIX
   if ( (fh = socket(AF_UNIX, SOCK_STREAM, 0)) == -1 )
    return -1;
 
@@ -385,7 +388,9 @@ int muroar_stream(int fh, int dir, int * stream, int codec, int rate, int channe
  // Send NEW_STREAM command:
  memset(buf, 0, 10);
  buf[1] = MUROAR_CMD_NEW_STREAM;
- buf[9] = 24; // 6 * int32 = 24 Byte
+ buf[2] = 0xFF; // byte 2 and 3 are mixer ID (must be -1)
+ buf[3] = 0xFF;
+ buf[9] = 24;   // 6 * int32 = 24 Byte
 
  if ( muroar_write(fh, buf, 10) != 10 ) {
   _CLOSE(fh);
