@@ -1,7 +1,7 @@
 //muroar.h:
 
 /*
- *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2009,2010
+ *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2009-2011
  *
  *  This file is part of µRoar,
  *  a minimalist library to access a RoarAudio Sound Server.
@@ -74,8 +74,8 @@ extern "C" {
 #define MUROAR_CMD_GET_META         22
 #define MUROAR_CMD_LIST_META        23
 #define MUROAR_CMD_BEEP             24
-#define MUROAR_CMD_GET_ACL          25
-#define MUROAR_CMD_SET_ACL          26
+#define MUROAR_CMD_AUTHCTL          25
+#define MUROAR_CMD_ACLCTL           26
 #define MUROAR_CMD_GET_STREAM_PARA  27
 #define MUROAR_CMD_SET_STREAM_PARA  28
 #define MUROAR_CMD_ATTACH           29
@@ -83,10 +83,26 @@ extern "C" {
 #define MUROAR_CMD_GETTIMEOFDAY     31
 #define MUROAR_CMD_WHOAMI           32
 
+#define MUROAR_CMD_DEVCTL           33 /* send control messages to devices */
+#define MUROAR_CMD_CAPS             34 /* send caps */
+#define MUROAR_CMD_WAIT             35 /* wait for an event */
+#define MUROAR_CMD_NOTIFY           36 /* asyncronus notify of events */
+#define MUROAR_CMD_SEEK             37 /* seek in stream */
+#define MUROAR_CMD_CLIENTCTL        38 /* like stream ctl, just for client connections */
+#define MUROAR_CMD_LOOKUP           39 /* lookup??? */
+#define MUROAR_CMD_CONCTL           40 /* change parameter for current connection */
+
 // special CMDs:
 #define MUROAR_CMD_OK              254 /* return value OK    */
 #define MUROAR_CMD_ERROR           255 /* return value ERROR */
 
+// consts for CAPS command:
+
+#define MUROAR_CF_REQUEST       0x0001
+#define MUROAR_CT_CAPS               0
+#define MUROAR_CT_STANDARDS          1
+
+// stream directions:
 #define MUROAR_PLAY_WAVE             1
 #define MUROAR_PLAY_MIDI            12
 #define MUROAR_PLAY_LIGHT           14
@@ -96,6 +112,8 @@ extern "C" {
 #define MUROAR_MONITOR_LIGHT        15
 #define MUROAR_FILTER_WAVE           4
 
+
+// Codecs:
 #define MUROAR_CODEC_PCM_S_LE     0x01
 #define MUROAR_CODEC_PCM_S_BE     0x02
 #define MUROAR_CODEC_PCM_S_PDP    0x03
